#!/usr/bin/bash

# Set up build environment
#
# e.g.:
# module purge
# module add compiler/gnu
:

# Build stream benchmark
make stream

# Set up OpenMP environment
export OMP_NUM_THREADS=2
export OMP_PROC_BIND=TRUE
export OMP_PLACES=cores

# Ltrace
#  * Filter for `alloc` and `free` functions calls within the stream binary
#    (ignoring these calls within libraries).
#  * Discard standard output

exec \
    ltrace \
        -f \
        --demangle \
        -e *alloc*@stream+free@stream \
        -c \
        ./stream >/dev/null

"
% time     seconds  usecs/call     calls      function
------ ----------- ----------- --------- --------------------
 80.21    0.004142         690         6 free
 19.79    0.001022         170         6 aligned_alloc
------ ----------- ----------- --------- --------------------
100.00    0.005164                    12 total

-> Each OpenMP Thread does its own memory allocation and free
"
