#!/usr/bin/bash

# Set up build environment
#
# e.g.:
# module purge
# module add \
#     compiler/gnu \
#     mpi/openmpi
# module add devel/strace
:

# Build rank_league benchmark
make rank_league

# Ltrace
#  * Only on first MPI rank (e.g. for data reduction)
#  * Count calls to MPI functions

exec mpirun -np 4 --bind-to core --map-by core bash -c \
      'if [[ ${OMPI_COMM_WORLD_RANK} -eq 0 ]]; then
           exec ltrace -c -e *MPI* \
                ./rank_league
       else
           exec ./rank_league
       fi'

"
****** Running bandwidth test ********
Total number of rounds:          3
Total number of loops per round: 200
Message size:                    100000
**************************************
Round number     3
**************************************
RANKS    RESULTS
________________
0 -- 1    544.14
0 -- 2    481.27
0 -- 3    527.33
1 -- 0    535.84
1 -- 2   4202.61
1 -- 3   3645.32
2 -- 0    488.79
2 -- 1   3594.82
2 -- 3   3029.95
3 -- 0    436.87
3 -- 1   3626.08
3 -- 2   3791.88
___________________________________________________________
Global statistics:
 MIN      436.87 between 3 and 0
 MAX     4202.61 between 1 and 2
 AVERAGE 2075.41

-> All communication with MPI rank 0 is much slower
-> Overhead of ltrace

% time     seconds  usecs/call     calls      function
------ ----------- ----------- --------- --------------------
 69.40    0.827191      827191         1 MPI_Init
  9.95    0.118649       14831         8 MPI_Waitall
  7.56    0.090102         112       800 MPI_Isend
  7.34    0.087449         109       800 MPI_Irecv
  4.82    0.057434       57434         1 MPI_Finalize
  0.34    0.004106         513         8 MPI_Sendrecv
  0.26    0.003043        1014         3 MPI_Recv
  0.19    0.002256         564         4 MPI_Barrier
  0.12    0.001464         183         8 MPI_Wtime
  0.01    0.000078          78         1 MPI_Comm_size
  0.01    0.000073          73         1 MPI_Get_processor_name
  0.01    0.000064          64         1 MPI_Comm_rank
------ ----------- ----------- --------- --------------------
100.00    1.191909                  1636 total
"
