#!/usr/bin/bash

# Set up strace and build environment
#
# e.g.:
# module purge
# module add \
#     compiler/gnu \
#     mpi/openmpi
# module add devel/strace
:

# Build rank_league benchmark
make rank_league

# Strace
#  * Only on first MPI rank
#  * Filter for `openat` syscalls,
#  * Show only successful syscalls
#  * grep for loaded dynamic libraries

exec mpirun -np 4 --bind-to core --map-by core bash -c \
      'if [[ ${OMPI_COMM_WORLD_RANK} -eq 0 ]]; then
           exec strace -e openat --status=successful -o"| grep [.]so" \
                ./rank_league
       else
           exec ./rank_league
       fi'

'
openat(AT_FDCWD, "/usr/lib/libmpi.so.40", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libc.so.6", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/etc/ld.so.cache", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libopen-rte.so.40", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libopen-pal.so.40", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libm.so.6", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libhwloc.so.15", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libgcc_s.so.1", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libz.so.1", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libevent_core-2.1.so.7", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libevent_pthreads-2.1.so.7", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libudev.so.1", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/libcap.so.2", O_RDONLY|O_CLOEXEC) = 3
openat(AT_FDCWD, "/usr/lib/openmpi/mca_shmem_mmap.so", O_RDONLY|O_CLOEXEC) = 6
openat(AT_FDCWD, "/usr/lib/openmpi/mca_shmem_sysv.so", O_RDONLY|O_CLOEXEC) = 6
openat(AT_FDCWD, "/usr/lib/openmpi/mca_shmem_posix.so", O_RDONLY|O_CLOEXEC) = 6
openat(AT_FDCWD, "/usr/lib/openmpi/mca_reachable_weighted.so", O_RDONLY|O_CLOEXEC) = 7
openat(AT_FDCWD, "/usr/lib/openmpi/mca_reachable_netlink.so", O_RDONLY|O_CLOEXEC) = 7
openat(AT_FDCWD, "/etc/ld.so.cache", O_RDONLY|O_CLOEXEC) = 7
openat(AT_FDCWD, "/usr/lib/libnl-3.so.200", O_RDONLY|O_CLOEXEC) = 7
openat(AT_FDCWD, "/usr/lib/openmpi/mca_schizo_flux.so", O_RDONLY|O_CLOEXEC) = 7
openat(AT_FDCWD, "/usr/lib/openmpi/mca_schizo_jsm.so", O_RDONLY|O_CLOEXEC) = 7
openat(AT_FDCWD, "/usr/lib/openmpi/mca_schizo_orte.so", O_RDONLY|O_CLOEXEC) = 7
openat(AT_FDCWD, "/usr/lib/openmpi/mca_schizo_slurm.so", O_RDONLY|O_CLOEXEC) = 7
openat(AT_FDCWD, "/usr/lib/openmpi/mca_schizo_ompi.so", O_RDONLY|O_CLOEXEC) = 7
openat(AT_FDCWD, "/usr/lib/openmpi/mca_ess_pmi.so", O_RDONLY|O_CLOEXEC) = 7
openat(AT_FDCWD, "/usr/lib/openmpi/mca_pmix_ext3x.so", O_RDONLY|O_CLOEXEC) = 10
openat(AT_FDCWD, "/etc/ld.so.cache", O_RDONLY|O_CLOEXEC) = 10
openat(AT_FDCWD, "/usr/lib/libpmix.so.2", O_RDONLY|O_CLOEXEC) = 10
openat(AT_FDCWD, "/usr/lib/openmpi/mca_pmix_flux.so", O_RDONLY|O_CLOEXEC) = 10
openat(AT_FDCWD, "/usr/lib/pmix/pmix_mca_pcompress_zlib.so", O_RDONLY|O_CLOEXEC) = 14
openat(AT_FDCWD, "/usr/lib/hwloc/hwloc_pci.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/etc/ld.so.cache", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/libpciaccess.so.0", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/hwloc/hwloc_xml_libxml.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/etc/ld.so.cache", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/libxml2.so.2", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/liblzma.so.5", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/libicuuc.so.72", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/libicudata.so.72", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/libstdc++.so.6", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_state_novm.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_state_tool.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_state_hnp.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_state_orted.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_state_app.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_errmgr_default_tool.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_errmgr_default_app.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_errmgr_default_hnp.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_errmgr_default_orted.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_op_avx.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_allocator_bucket.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_allocator_basic.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_rcache_gpusm.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/etc/ld.so.cache", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/libmca_common_cuda.so.40", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_rcache_rgpusm.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_rcache_grdma.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_mpool_hugepage.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_bml_r2.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_btl_smcuda.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/etc/ld.so.cache", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/libmca_common_sm.so.40", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_btl_tcp.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_btl_sm.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_btl_self.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_btl_vader.so", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/etc/ld.so.cache", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/etc/ld.so.cache", O_RDONLY|O_CLOEXEC) = 15
openat(AT_FDCWD, "/usr/lib/openmpi/mca_pml_monitoring.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/etc/ld.so.cache", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/libmca_common_monitoring.so.50", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_pml_cm.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_pml_ob1.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_vprotocol_pessimist.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_cuda.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_adapt.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_self.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_han.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_tuned.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_sm.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_sync.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_monitoring.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_inter.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_libnbc.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_coll_basic.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_osc_sm.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_osc_monitoring.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_osc_rdma.so", O_RDONLY|O_CLOEXEC) = 16
openat(AT_FDCWD, "/usr/lib/openmpi/mca_osc_pt2pt.so", O_RDONLY|O_CLOEXEC) = 16
'
