#!/usr/bin/bash

# Set up valgrind and build environment
#
# e.g.:
# module purge
# export VALGRIND=true
# module add \
#     compiler/gnu \
#     mpi/openmpi \
#     devel/valgrind
#
# or to update environment
#
# export VALGRIND=true
# module update
export MPI_ROOT=${MPI_ROOT:-/usr}

# To check if valgrind tool memchecker is available in OpenMPI, simply run this command:
ompi_info | grep memchecker

# Build rank_league benchmark with debug symbols and low optimization settings
#
# e.g.:
# mpicc -O1 -ggdb rank_league.c -o rank_league
make rank_league

# Examine rank_leage benchmark with valgrind memchecker. Use one output file per rank
mpirun -np 4 --bind-to core --map-by core bash -c \
      'valgrind \
           --log-file=valgrind.out.${OMPI_COMM_WORLD_RANK} \
           --suppressions="${MPI_ROOT}/share/openmpi/openmpi-valgrind.supp" \
           --suppressions="${MPI_ROOT}/share/pmix/pmix-valgrind.supp" \
           --suppressions="/usr/share/hwloc/hwloc-valgrind.supp" \
           ./rank_league
      '

# -rw-r--r-- 1 holgerob users 22473 11. Mai 09:31 valgrind.out.0
# -rw-r--r-- 1 holgerob users 19755 11. Mai 09:31 valgrind.out.1
# -rw-r--r-- 1 holgerob users 17591 11. Mai 09:31 valgrind.out.2
# -rw-r--r-- 1 holgerob users 19755 11. Mai 09:31 valgrind.out.3
# -> many false positives

mpirun -np 4 --bind-to core --map-by core \
    ./rank_league
# -> massive increase in runtime

