#!/usr/bin/bash

# Set up valgrind and build environment
#
# e.g.:
# module purge
# export VALGRIND=true
# module add \
#     compiler/gnu \
#     mpi/openmpi \
#     devel/valgrind
#
# or to update environment
#
# export VALGRIND=true
# module update
export VALGRIND_LIB_DIR="${VALGRIND_LIB_DIR:-${HOME}/.local/lib}"

# Build rank_league benchmark with debug symbols and low optimization settings
#
# e.g.:
# mpicc -O1 -ggdb rank_league.c -o rank_league
make rank_league

# Examine rank_league benchmark with valgrind MPI wrapper
mpirun -np 4 --bind-to core --map-by core bash -c \
      'LD_PRELOAD="${VALGRIND_LIB_DIR}/valgrind/libmpiwrap-amd64-linux.so" \
       MPIWRAP_DEBUG="warn" \
       valgrind \
           --log-file=valgrind.out.${OMPI_COMM_WORLD_RANK} \
           ./rank_league 2>valgrind.stderr.${OMPI_COMM_WORLD_RANK}'

# valgrind.stderr.0:

# valgrind MPI wrappers 785165: Active for pid 785165
# valgrind MPI wrappers 785165: Try MPIWRAP_DEBUG=help for possible options
# valgrind MPI wrappers 785165: warning: no wrapper for PMPI_Get_processor_name
# valgrind MPI wrappers 785165: warning: no wrapper for PMPI_Barrier

# -rw-r--r-- 1 holgerob users  3534 11. Mai 14:28 valgrind.out.0
# -rw-r--r-- 1 holgerob users  4244 11. Mai 14:28 valgrind.out.1
# -rw-r--r-- 1 holgerob users  4244 11. Mai 14:28 valgrind.out.2
# -rw-r--r-- 1 holgerob users  3534 11. Mai 14:28 valgrind.out.3

# -> fewer false positives

#-> still massive increase in runtime
